==> jc-1.4.0.tar.gz: soot/jimple/toolkits/callgraph/ReachableMethods.h <==
// public class soot.jimple.toolkits.callgraph.ReachableMethods

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 5f8ac62e0dc34c07 soot_jimple_toolkits_callgraph_ReachableMethods

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_jimple_toolkits_callgraph_ReachableMethods_H_
#define _JC_soot_jimple_toolkits_callgraph_ReachableMethods_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_Collection$object;
struct _jc_java_util_Iterator$object;
struct _jc_java_util_List$object;
struct _jc_java_util_Set$object;
struct _jc_soot_jimple_toolkits_callgraph_CallGraph$object;
struct _jc_soot_jimple_toolkits_callgraph_Filter$object;
struct _jc_soot_jimple_toolkits_callgraph_MethodOrMethodContext$object;
struct _jc_soot_util_queue_ChunkedQueue$object;
struct _jc_soot_util_queue_QueueReader$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_callgraph_ReachableMethods$sub_refs	_jc_soot_jimple_toolkits_callgraph_ReachableMethods$sub_refs;
typedef struct _jc_soot_jimple_toolkits_callgraph_ReachableMethods$sub_nonrefs	_jc_soot_jimple_toolkits_callgraph_ReachableMethods$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_callgraph_ReachableMethods$refs	_jc_soot_jimple_toolkits_callgraph_ReachableMethods$refs;
typedef struct _jc_soot_jimple_toolkits_callgraph_ReachableMethods$nonrefs	_jc_soot_jimple_toolkits_callgraph_ReachableMethods$nonrefs;
typedef struct _jc_soot_jimple_toolkits_callgraph_ReachableMethods$object	_jc_soot_jimple_toolkits_callgraph_ReachableMethods$object;

typedef const struct _jc_soot_jimple_toolkits_callgraph_ReachableMethods$vmethods	_jc_soot_jimple_toolkits_callgraph_ReachableMethods$vmethods;
typedef const struct _jc_soot_jimple_toolkits_callgraph_ReachableMethods$vtable	_jc_soot_jimple_toolkits_callgraph_ReachableMethods$vtable;
typedef const struct _jc_soot_jimple_toolkits_callgraph_ReachableMethods$vtype	_jc_soot_jimple_toolkits_callgraph_ReachableMethods$vtype;

// Constructors
extern void _jc_soot_jimple_toolkits_callgraph_ReachableMethods$method$_init$1bd07d3affa43bdd(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_ReachableMethods$object *, struct _jc_soot_jimple_toolkits_callgraph_CallGraph$object *, struct _jc_object *);
extern void _jc_soot_jimple_toolkits_callgraph_ReachableMethods$method$_init$47d5d1c657e8bbbb(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_ReachableMethods$object *, struct _jc_soot_jimple_toolkits_callgraph_CallGraph$object *, struct _jc_object *);
extern void _jc_soot_jimple_toolkits_callgraph_ReachableMethods$method$_init$29022616f93f1ef6(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_ReachableMethods$object *, struct _jc_soot_jimple_toolkits_callgraph_CallGraph$object *, struct _jc_object *, struct _jc_soot_jimple_toolkits_callgraph_Filter$object *);

// Virtual methods
extern void _jc_soot_jimple_toolkits_callgraph_ReachableMethods$method$addMethod$d93f9fcf807b559b(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_ReachableMethods$object *, struct _jc_object *);
extern void _jc_soot_jimple_toolkits_callgraph_ReachableMethods$method$addMethods$96544f9973619dcd(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_ReachableMethods$object *, struct _jc_object *);
extern jboolean _jc_soot_jimple_toolkits_callgraph_ReachableMethods$method$contains$c5496c14a38f43fa(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_ReachableMethods$object *, struct _jc_object *);
extern struct _jc_soot_util_queue_QueueReader$object *_jc_soot_jimple_toolkits_callgraph_ReachableMethods$method$listener$6c88d190272b7f47(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_ReachableMethods$object *);
extern struct _jc_soot_util_queue_QueueReader$object *_jc_soot_jimple_toolkits_callgraph_ReachableMethods$method$newListener$faa22950086d1ce9(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_ReachableMethods$object *);
extern jint _jc_soot_jimple_toolkits_callgraph_ReachableMethods$method$size$345df5220fc60ade(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_ReachableMethods$object *);
extern void _jc_soot_jimple_toolkits_callgraph_ReachableMethods$method$update$1bc19abd93504b5c(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_ReachableMethods$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_callgraph_ReachableMethods$method_info$addMethod$d93f9fcf807b559b;
extern _jc_method _jc_soot_jimple_toolkits_callgraph_ReachableMethods$method_info$addMethods$96544f9973619dcd;
extern _jc_method _jc_soot_jimple_toolkits_callgraph_ReachableMethods$method_info$contains$c5496c14a38f43fa;
extern _jc_method _jc_soot_jimple_toolkits_callgraph_ReachableMethods$method_info$listener$6c88d190272b7f47;
extern _jc_method _jc_soot_jimple_toolkits_callgraph_ReachableMethods$method_info$newListener$faa22950086d1ce9;
extern _jc_method _jc_soot_jimple_toolkits_callgraph_ReachableMethods$method_info$size$345df5220fc60ade;
extern _jc_method _jc_soot_jimple_toolkits_callgraph_ReachableMethods$method_info$update$1bc19abd93504b5c;

// Virtual methods structure
struct _jc_soot_jimple_toolkits_callgraph_ReachableMethods$vmethods {
	void	(*addMethod$d93f9fcf807b559b)(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_ReachableMethods$object *, struct _jc_object *);
	void	(*addMethods$96544f9973619dcd)(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_ReachableMethods$object *, struct _jc_object *);
	jboolean	(*contains$c5496c14a38f43fa)(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_ReachableMethods$object *, struct _jc_object *);
	struct _jc_soot_util_queue_QueueReader$object	*(*listener$6c88d190272b7f47)(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_ReachableMethods$object *);
	struct _jc_soot_util_queue_QueueReader$object	*(*newListener$faa22950086d1ce9)(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_ReachableMethods$object *);
	jint	(*size$345df5220fc60ade)(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_ReachableMethods$object *);
	void	(*update$1bc19abd93504b5c)(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_ReachableMethods$object *);
};

// Vtable
struct _jc_soot_jimple_toolkits_callgraph_ReachableMethods$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_toolkits_callgraph_ReachableMethods$vmethods	soot_jimple_toolkits_callgraph_ReachableMethods;
};

// Vtype
struct _jc_soot_jimple_toolkits_callgraph_ReachableMethods$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_callgraph_ReachableMethods$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_callgraph_ReachableMethods$sub_refs {
	struct _jc_soot_jimple_toolkits_callgraph_CallGraph$object	*cg;
	struct _jc_object	*entryPoints;
	struct _jc_object	*edgeSource;
	struct _jc_soot_util_queue_ChunkedQueue$object	*reachables;
	struct _jc_object	*set;
	struct _jc_soot_util_queue_QueueReader$object	*unprocessedMethods;
	struct _jc_soot_util_queue_QueueReader$object	*allReachables;
	struct _jc_soot_jimple_toolkits_callgraph_Filter$object	*filter;
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_callgraph_ReachableMethods$refs {
    _jc_soot_jimple_toolkits_callgraph_ReachableMethods$sub_refs	soot_jimple_toolkits_callgraph_ReachableMethods;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_callgraph_ReachableMethods$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_callgraph_ReachableMethods$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_toolkits_callgraph_ReachableMethods$sub_nonrefs	soot_jimple_toolkits_callgraph_ReachableMethods;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_callgraph_ReachableMethods$object {
	_jc_soot_jimple_toolkits_callgraph_ReachableMethods$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_callgraph_ReachableMethods$vtype	*vtype;
	_jc_soot_jimple_toolkits_callgraph_ReachableMethods$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_callgraph_ReachableMethods$vtype _jc_soot_jimple_toolkits_callgraph_ReachableMethods$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_callgraph_ReachableMethods, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_callgraph_ReachableMethods$class_object;

#endif	/* _JC_soot_jimple_toolkits_callgraph_ReachableMethods_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/toolkits/callgraph/ReachableMethods.h <==
// public class soot.jimple.toolkits.callgraph.ReachableMethods

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 5f8ac62e0dc34c07 soot_jimple_toolkits_callgraph_ReachableMethods

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_jimple_toolkits_callgraph_ReachableMethods_H_
#define _JC_soot_jimple_toolkits_callgraph_ReachableMethods_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_Collection$object;
struct _jc_java_util_Iterator$object;
struct _jc_java_util_List$object;
struct _jc_java_util_Set$object;
struct _jc_soot_jimple_toolkits_callgraph_CallGraph$object;
struct _jc_soot_jimple_toolkits_callgraph_Filter$object;
struct _jc_soot_jimple_toolkits_callgraph_MethodOrMethodContext$object;
struct _jc_soot_util_queue_ChunkedQueue$object;
struct _jc_soot_util_queue_QueueReader$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_callgraph_ReachableMethods$sub_refs	_jc_soot_jimple_toolkits_callgraph_ReachableMethods$sub_refs;
typedef struct _jc_soot_jimple_toolkits_callgraph_ReachableMethods$sub_nonrefs	_jc_soot_jimple_toolkits_callgraph_ReachableMethods$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_callgraph_ReachableMethods$refs	_jc_soot_jimple_toolkits_callgraph_ReachableMethods$refs;
typedef struct _jc_soot_jimple_toolkits_callgraph_ReachableMethods$nonrefs	_jc_soot_jimple_toolkits_callgraph_ReachableMethods$nonrefs;
typedef struct _jc_soot_jimple_toolkits_callgraph_ReachableMethods$object	_jc_soot_jimple_toolkits_callgraph_ReachableMethods$object;

typedef const struct _jc_soot_jimple_toolkits_callgraph_ReachableMethods$vmethods	_jc_soot_jimple_toolkits_callgraph_ReachableMethods$vmethods;
typedef const struct _jc_soot_jimple_toolkits_callgraph_ReachableMethods$vtable	_jc_soot_jimple_toolkits_callgraph_ReachableMethods$vtable;
typedef const struct _jc_soot_jimple_toolkits_callgraph_ReachableMethods$vtype	_jc_soot_jimple_toolkits_callgraph_ReachableMethods$vtype;

// Constructors
extern void _jc_soot_jimple_toolkits_callgraph_ReachableMethods$method$_init$1bd07d3affa43bdd(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_ReachableMethods$object *, struct _jc_soot_jimple_toolkits_callgraph_CallGraph$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_toolkits_callgraph_ReachableMethods$method$_init$47d5d1c657e8bbbb(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_ReachableMethods$object *, struct _jc_soot_jimple_toolkits_callgraph_CallGraph$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_toolkits_callgraph_ReachableMethods$method$_init$29022616f93f1ef6(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_ReachableMethods$object *, struct _jc_soot_jimple_toolkits_callgraph_CallGraph$object *, struct _jc_object *, struct _jc_soot_jimple_toolkits_callgraph_Filter$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_toolkits_callgraph_ReachableMethods$method$addMethod$d93f9fcf807b559b(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_ReachableMethods$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_toolkits_callgraph_ReachableMethods$method$addMethods$96544f9973619dcd(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_ReachableMethods$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern jboolean _jc_soot_jimple_toolkits_callgraph_ReachableMethods$method$contains$c5496c14a38f43fa(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_ReachableMethods$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_soot_util_queue_QueueReader$object *_jc_soot_jimple_toolkits_callgraph_ReachableMethods$method$listener$6c88d190272b7f47(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_ReachableMethods$object *) _JC_JCNI_ATTR;
extern struct _jc_soot_util_queue_QueueReader$object *_jc_soot_jimple_toolkits_callgraph_ReachableMethods$method$newListener$faa22950086d1ce9(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_ReachableMethods$object *) _JC_JCNI_ATTR;
extern jint _jc_soot_jimple_toolkits_callgraph_ReachableMethods$method$size$345df5220fc60ade(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_ReachableMethods$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_toolkits_callgraph_ReachableMethods$method$update$1bc19abd93504b5c(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_ReachableMethods$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_callgraph_ReachableMethods$method_info$addMethod$d93f9fcf807b559b;
extern _jc_method _jc_soot_jimple_toolkits_callgraph_ReachableMethods$method_info$addMethods$96544f9973619dcd;
extern _jc_method _jc_soot_jimple_toolkits_callgraph_ReachableMethods$method_info$contains$c5496c14a38f43fa;
extern _jc_method _jc_soot_jimple_toolkits_callgraph_ReachableMethods$method_info$listener$6c88d190272b7f47;
extern _jc_method _jc_soot_jimple_toolkits_callgraph_ReachableMethods$method_info$newListener$faa22950086d1ce9;
extern _jc_method _jc_soot_jimple_toolkits_callgraph_ReachableMethods$method_info$size$345df5220fc60ade;
extern _jc_method _jc_soot_jimple_toolkits_callgraph_ReachableMethods$method_info$update$1bc19abd93504b5c;

// Virtual methods structure
struct _jc_soot_jimple_toolkits_callgraph_ReachableMethods$vmethods {
	void	(*addMethod$d93f9fcf807b559b)(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_ReachableMethods$object *, struct _jc_object *) _JC_JCNI_ATTR;
	void	(*addMethods$96544f9973619dcd)(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_ReachableMethods$object *, struct _jc_object *) _JC_JCNI_ATTR;
	jboolean	(*contains$c5496c14a38f43fa)(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_ReachableMethods$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_soot_util_queue_QueueReader$object	*(*listener$6c88d190272b7f47)(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_ReachableMethods$object *) _JC_JCNI_ATTR;
	struct _jc_soot_util_queue_QueueReader$object	*(*newListener$faa22950086d1ce9)(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_ReachableMethods$object *) _JC_JCNI_ATTR;
	jint	(*size$345df5220fc60ade)(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_ReachableMethods$object *) _JC_JCNI_ATTR;
	void	(*update$1bc19abd93504b5c)(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_ReachableMethods$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_toolkits_callgraph_ReachableMethods$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_toolkits_callgraph_ReachableMethods$vmethods	soot_jimple_toolkits_callgraph_ReachableMethods;
};

// Vtype
struct _jc_soot_jimple_toolkits_callgraph_ReachableMethods$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_callgraph_ReachableMethods$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_callgraph_ReachableMethods$sub_refs {
	struct _jc_soot_jimple_toolkits_callgraph_CallGraph$object	*cg;
	struct _jc_object	*entryPoints;
	struct _jc_object	*edgeSource;
	struct _jc_soot_util_queue_ChunkedQueue$object	*reachables;
	struct _jc_object	*set;
	struct _jc_soot_util_queue_QueueReader$object	*unprocessedMethods;
	struct _jc_soot_util_queue_QueueReader$object	*allReachables;
	struct _jc_soot_jimple_toolkits_callgraph_Filter$object	*filter;
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_callgraph_ReachableMethods$refs {
    _jc_soot_jimple_toolkits_callgraph_ReachableMethods$sub_refs	soot_jimple_toolkits_callgraph_ReachableMethods;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_callgraph_ReachableMethods$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_callgraph_ReachableMethods$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_toolkits_callgraph_ReachableMethods$sub_nonrefs	soot_jimple_toolkits_callgraph_ReachableMethods;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_callgraph_ReachableMethods$object {
	_jc_soot_jimple_toolkits_callgraph_ReachableMethods$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_callgraph_ReachableMethods$vtype	*vtype;
	_jc_soot_jimple_toolkits_callgraph_ReachableMethods$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_callgraph_ReachableMethods$vtype _jc_soot_jimple_toolkits_callgraph_ReachableMethods$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_callgraph_ReachableMethods, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_callgraph_ReachableMethods$class_object;

#endif	/* _JC_soot_jimple_toolkits_callgraph_ReachableMethods_H_ */
